# 3rd party completion loader for nvm
#
# This serves as a fallback in case the completion is not installed otherwise.

# shellcheck disable=SC1091
[[ ${NVM_DIR-} && -r $NVM_DIR/bash_completion ]] && . "$NVM_DIR"/bash_completion
